==> jacderida-exp2-adder-0.1.0.crate: jacderida-exp2-adder-0.1.0/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## v0.1.0 (2021-10-19)

### New Features

 - <csr-id-9aecbb2e6a641e50fb1c97bfbc3fbca200dee7cb/> rename crate to add-lib
 - <csr-id-c71961b732d9146f08ea5f428e2fe75259b0d2e0/> create adder binary
   This is just duplicating the little workspace setup described in the Rust book. The strange
   `jacderida-exp` prefixes are just to make sure the crate names are unique and clearly designated as
   being experimental. I plan to publish these to my own account on crates.io.

### Bug Fixes

 - <csr-id-d17cf9b31d923d042767a8ddc2d77792bc4eb8ee/> use correct input name for action

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 2 commits contributed to the release.
 - 1 commit where understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' where seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - Release jacderida-exp2-add-lib v0.1.0, jacderida-exp2-adder v0.1.0 ([`e50bf48`](https://github.com/git//jacderida/workspace-release-exp.git/commit/e50bf48ad1bd954a3920e7ab6f0177f7955125dd))
    - rename crates to exp2 ([`1b64860`](https://github.com/git//jacderida/workspace-release-exp.git/commit/1b64860257581fd5a94ca87d1b674eefb97ece40))
</details>

==> jacderida-exp2-adder-0.1.1.crate: jacderida-exp2-adder-0.1.1/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## v0.1.1 (2021-10-19)

### New Features

 - <csr-id-55b9daf4c67dade31c2510f11cc741755b3f057d/> provide function for adding 5

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 2 commits contributed to the release.
 - 1 commit where understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' where seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - Release jacderida-exp2-add-lib v0.1.1, jacderida-exp2-adder v0.1.1 ([`633f876`](https://github.com/git//jacderida/workspace-release-exp.git/commit/633f876e400e5a74e841a0846cf51e18a312e6a2))
    - provide function for adding 5 ([`55b9daf`](https://github.com/git//jacderida/workspace-release-exp.git/commit/55b9daf4c67dade31c2510f11cc741755b3f057d))
</details>

## v0.1.0 (2021-10-19)

### New Features

 - <csr-id-9aecbb2e6a641e50fb1c97bfbc3fbca200dee7cb/> rename crate to add-lib
 - <csr-id-c71961b732d9146f08ea5f428e2fe75259b0d2e0/> create adder binary
   This is just duplicating the little workspace setup described in the Rust book. The strange
   `jacderida-exp` prefixes are just to make sure the crate names are unique and clearly designated as
   being experimental. I plan to publish these to my own account on crates.io.

### Bug Fixes

 - <csr-id-d17cf9b31d923d042767a8ddc2d77792bc4eb8ee/> use correct input name for action

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 3 commits contributed to the release.
 - 1 commit where understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' where seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - Release jacderida-exp2-adder v0.1.0 ([`8e5b8ac`](https://github.com/git//jacderida/workspace-release-exp.git/commit/8e5b8ac45f09a553ba2ebfcca6b5485239a8eb57))
    - Release jacderida-exp2-add-lib v0.1.0, jacderida-exp2-adder v0.1.0 ([`e50bf48`](https://github.com/git//jacderida/workspace-release-exp.git/commit/e50bf48ad1bd954a3920e7ab6f0177f7955125dd))
    - rename crates to exp2 ([`1b64860`](https://github.com/git//jacderida/workspace-release-exp.git/commit/1b64860257581fd5a94ca87d1b674eefb97ece40))
</details>
